#[non_exhaustive]pub struct DocumentReferenceDraft<'a> {
pub location: Option<&'a str>,
pub identification: Option<&'a str>,
pub name: Option<&'a str>,
pub description: Option<&'a str>,
pub referenced_document: Option<EntityId>,
}Expand description
Draft for one IfcDocumentReference.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: Option<&'a str>Location (URI) of the reference; at least one of location/identification/name must be given.
identification: Option<&'a str>Identification code, when stated (ItemReference in IFC2X3).
name: Option<&'a str>Name; exactly one of name and referenced_document must be given.
description: Option<&'a str>Description of the reference, when stated. IFC4 onwards.
referenced_document: Option<EntityId>ReferencedDocument: an IfcDocumentInformation; exactly one of
name and this must be given. IFC4 onwards: IFC2X3 links the other
way, so there name is required.
Implementations
Sourceimpl<'a> DocumentReferenceDraft<'a>
impl<'a> DocumentReferenceDraft<'a>
Sourcepub fn location(self, value: &'a str) -> Self
pub fn location(self, value: &'a str) -> Self
Sets location: Location (URI) of the reference; at least one of
location/identification/name must be given.
Sourcepub fn identification(self, value: &'a str) -> Self
pub fn identification(self, value: &'a str) -> Self
Sets identification: Identification code, when stated
(ItemReference in IFC2X3).
Sourcepub fn name(self, value: &'a str) -> Self
pub fn name(self, value: &'a str) -> Self
Sets name: Name; exactly one of name and referenced_document
must be given.
Sourcepub fn description(self, value: &'a str) -> Self
pub fn description(self, value: &'a str) -> Self
Sets description: Description of the reference, when stated. IFC4
onwards.
Sourcepub fn referenced_document(self, value: EntityId) -> Self
pub fn referenced_document(self, value: EntityId) -> Self
Sets referenced_document: ReferencedDocument: an
IfcDocumentInformation; exactly one of name and this must be given.
IFC4 onwards: IFC2X3 links the other way, so there name is required.