#[non_exhaustive]pub struct EffectiveClassifications<'m> {
pub occurrence: Vec<ClassificationAssignment<'m>>,
pub type_object: Option<EntityId>,
pub inherited: Vec<ClassificationAssignment<'m>>,
}Expand description
Classification assignments effective on an object: those directly assigned plus, when the object has an IfcRelDefinesByType type, those inherited from that type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.occurrence: Vec<ClassificationAssignment<'m>>Assignments made directly on the queried occurrence object.
type_object: Option<EntityId>Id of the object’s IfcRelDefinesByType type, when unambiguous.
inherited: Vec<ClassificationAssignment<'m>>Assignments made on the type object, inherited by the occurrence.